Config

Struct Config 

pub struct Config {
    pub initial_max_send_streams: usize,
    pub local_max_buffer_size: usize,
    pub local_next_stream_id: StreamId,
    pub local_push_enabled: bool,
    pub extended_connect_protocol_enabled: bool,
    pub local_reset_duration: Duration,
    pub local_reset_max: usize,
    pub remote_reset_max: usize,
    pub remote_init_window_sz: u32,
    pub remote_max_initiated: Option<usize>,
    pub local_max_error_reset_streams: Option<usize>,
    pub data_frame_budget: usize,
}

Fields

initial_max_send_streams: usize

Initial maximum number of locally initiated streams. After receiving a Settings frame from the remote peer, the connection will overwrite this value with the MAX_CONCURRENT_STREAMS specified in the frame.

local_max_buffer_size: usize

Max amount of DATA bytes to buffer per stream.

local_next_stream_id: StreamId

The stream ID to start the next local stream with

local_push_enabled: bool

If the local peer is willing to receive push promises

extended_connect_protocol_enabled: bool

If extended connect protocol is enabled.

local_reset_duration: Duration

How long a locally reset stream should ignore frames

local_reset_max: usize

Maximum number of locally reset streams to keep at a time

remote_reset_max: usize

Maximum number of remotely reset “pending accept” streams to keep at a time. Going over this number results in a connection error.

remote_init_window_sz: u32

Initial window size of remote initiated streams

remote_max_initiated: Option<usize>

Maximum number of remote initiated streams

local_max_error_reset_streams: Option<usize>

Maximum number of locally reset streams due to protocol error across the lifetime of the connection.

When this gets exceeded, we issue GOAWAYs.

data_frame_budget: usize

connection-level budget (in bytes) for DATA framing overhead.

Default 25600 bytes